TARGET=$1
COMMUNITY=$2

echo system mib ===================================
snmpwalk -c $COMMUNITY -v 1 $TARGET system
echo interfaces mib ===================================
snmpwalk -c $COMMUNITY -v 1 $TARGET interfaces
echo ifmib mib ===================================
snmpwalk -c $COMMUNITY -v 2c $TARGET ifmib
echo cisco stack mib =====================
snmpwalk -v 1 -c $COMMUNITY $TARGET .1.3.6.1.4.1.9.5
echo old cisco interface mib =====================
snmpwalk -v 1 -c $COMMUNITY $TARGET .1.3.6.1.4.1.9.2.2.1.1.28
# get various one-offs for temp, memory, cpu, etc.
echo cpu1min
snmpwalk -v 1 -c $COMMUNITY $TARGET .1.3.6.1.4.1.9.2.1.57.0
echo tempInlet
snmpwalk -v 1 -c $COMMUNITY $TARGET .1.3.6.1.4.1.9.9.13.1.3.1.3.1
echo mem5minUsed
snmpwalk -v 1 -c $COMMUNITY $TARGET .1.3.6.1.4.1.9.9.48.1.1.1.5.1
echo 1900bandwidth
snmpwalk -v 1 -c $COMMUNITY $TARGET .1.3.6.1.4.1.437.1.1.3.7.1.0
echo 5000bandwidth
snmpwalk -v 1 -c $COMMUNITY $TARGET .1.3.6.1.4.1.9.5.1.1.8.0
#echo temperature on some cisco beasties
#snmpwalk -On -v 1 -c $COMMUNITY $TARGET .1.3.6.1.4.1.9.9.13.1.3.1.3.1
~
